@@ -29,7 +29,7 @@ class GitbucketControl:
         if login == DEFAULT_LOGIN:
             gb.change_password(DEFAULT_LOGIN, DEFAULT_PASSWORD, password)
         else:
-            gb.create_account(login, password, isAdmin=True)
+            gb.create_account(DEFAULT_LOGIN, DEFAULT_PASSWORD, login, password, isAdmin=True)
             gb.disable_account(login, password, user_name_to_disable=DEFAULT_LOGIN)
 
         self.insider.add_service(SERVICE_NAME, PROTOCOL, SERVICE_TYPE, PORT, URL)
